@@ -39,14 +39,14 @@ extern "C" {
  *
  * Format: major * 10000 + minor * 100 + release
  */
-#define RASQAL_VERSION 929
+#define RASQAL_VERSION 930
 
 /**
  * RASQAL_VERSION_STRING:
  *
  * Rasqal library version string
  */
-#define RASQAL_VERSION_STRING "0.9.29"
+#define RASQAL_VERSION_STRING "0.9.30"
 
 /**
  * RASQAL_VERSION_MAJOR:
@@ -67,7 +67,7 @@ extern "C" {
  *
  * Rasqal library release
  */
-#define RASQAL_VERSION_RELEASE 29
+#define RASQAL_VERSION_RELEASE 30
 
 
 /**
@@ -202,7 +202,7 @@ extern const char * const rasqal_home_url_string;
  *
  * Version of Raptor that Rasqal was configured against.
  */
-#define RASQAL_RAPTOR_VERSION 20007
+#define RASQAL_RAPTOR_VERSION 20009
 
 
 /* Public structures */
@@ -934,7 +934,7 @@ typedef unsigned char* (*rasqal_generate_bnodeid_handler)(rasqal_world* world, v
 
 /**
  * rasqal_query_verb:
- * @RASQAL_QUERY_VERB_SELECT: RDQL/SPARQL query select verb. 
+ * @RASQAL_QUERY_VERB_SELECT: SPARQL query select verb. 
  * @RASQAL_QUERY_VERB_CONSTRUCT: SPARQL query construct verb.
  * @RASQAL_QUERY_VERB_DESCRIBE: SPARQL query describe verb.
  * @RASQAL_QUERY_VERB_ASK: SPARQL query ask verb.
@@ -1480,7 +1480,7 @@ unsigned char* rasqal_query_escape_counted_string(rasqal_query* query, const uns
 RASQAL_API
 rasqal_data_graph* rasqal_new_data_graph_from_uri(rasqal_world* world, raptor_uri* uri, raptor_uri* name_uri, int flags, const char* format_type, const char* format_name, raptor_uri* format_uri);
 RASQAL_API
-rasqal_data_graph* rasqal_new_data_graph_from_iostream(rasqal_world* world, raptor_iostream* iostr, raptor_uri* base_uri, raptor_uri* name_uri, int flags, const char* format_type, const char* format_name, raptor_uri* format_uri);
+rasqal_data_graph* rasqal_new_data_graph_from_iostream(rasqal_world* world, raptor_iostream* iostr, raptor_uri* base_uri, raptor_uri* name_uri, unsigned int flags, const char* format_type, const char* format_name, raptor_uri* format_uri);
 RASQAL_API
 rasqal_data_graph* rasqal_new_data_graph_from_data_graph(rasqal_data_graph* dg);
 RASQAL_API
@@ -1494,7 +1494,7 @@ int rasqal_data_graph_print(rasqal_data_graph* dg, FILE* fh);
  * @RASQAL_COMPARE_NOCASE: String comparisons are case independent.
  * @RASQAL_COMPARE_XQUERY: XQuery comparsion rules apply.
  * @RASQAL_COMPARE_RDF:    RDF Term comparsion rules apply.
- * @RASQAL_COMPARE_URI:    Allow comparison of URIs and allow strings to have a boolean value (for RDQL)
+ * @RASQAL_COMPARE_URI:    Allow comparison of URIs and allow strings to have a boolean value (unused; was for RDQL)
  * @RASQAL_COMPARE_SAMETERM: SPARQL sameTerm() builtin rules apply.
  *
  * Flags for rasqal_expression_evaluate(), rasqal_literal_compare() or
@@ -1618,6 +1618,8 @@ rasqal_literal* rasqal_new_typed_literal(rasqal_world* world, rasqal_literal_typ
 RASQAL_API
 rasqal_literal* rasqal_new_double_literal(rasqal_world* world, double d);
 RASQAL_API
+rasqal_literal* rasqal_new_floating_literal(rasqal_world *world, rasqal_literal_type type, double d);
+RASQAL_API RASQAL_DEPRECATED
 rasqal_literal* rasqal_new_float_literal(rasqal_world* world, float f);
 RASQAL_API
 rasqal_literal* rasqal_new_uri_literal(rasqal_world* world, raptor_uri* uri);
